pub enum SamplingStrategy {
Full,
Random {
limit: usize,
},
ReservoirPK {
sample_size: usize,
pk: String,
},
TableSample {
percentage: f32,
limit: usize,
},
}Expand description
Sampling strategy selection based on table size
Variants
Full
Full table scan - when sample_size >= row_count No randomization, deterministic results
Random
Random sampling for smaller tables (< 100k rows) Simple ORDER BY Random() LIMIT N
ReservoirPK
Reservoir sampling for medium tables (100K - 10M rows) uses primary key based random sampling for better performance
TableSample
TABLESAMPLE for larger tables (> 10M rows) Postgresql’s built in sampling - fast and no table locks
Implementations
Sourceimpl SamplingStrategy
impl SamplingStrategy
Sourcepub async fn auto_select(
pool: &PgPool,
schema: &str,
table: &str,
estimated_rows: Option<i64>,
sample_size: usize,
) -> Result<Self, Error>
pub async fn auto_select( pool: &PgPool, schema: &str, table: &str, estimated_rows: Option<i64>, sample_size: usize, ) -> Result<Self, Error>
Auto select the best sampling strat based on table size
Strat selection
- < 100k rows: Random sampling
- 100k - 10M rows: Resevoir sampling with PK
- 10M rows: TABLESAMPLE
Sourcepub fn max_samples(&self) -> usize
pub fn max_samples(&self) -> usize
Get the max number of samples that this strat should return